@@ -17,7 +17,7 @@ class LanzouDirectory(BaseTable):
                            )
         self.create()
         self.drive = LanZouDrive()
-        
+
         self.drive.login_by_cookie()
         self.drive.ignore_limits()
 
@@ -62,4 +62,4 @@ class LanzouDirectory(BaseTable):
 
     def sync(self, path):
         def filter_fun(x): return x.endswith('.csv')
-        self.drive.sync_files(path, self.fid, remove_local=False, filter_fun=filter_fun)
+        self.drive.sync_files(path, self.fid, remove_local=True, filter_fun=filter_fun)
