@@ -73,7 +73,7 @@ class DataFileProperty:
         self.file_pro = FileProperty(exchange_name=exchange.name.lower(), path=path, freq=freq,
                                      data_type=data_type, timeframe=timeframe, start_date=start_date, end_date=end_date,
                                      file_format=file_format)
-        self.drive = LanzouDirectory(fid=5679873)
+        self.drive = LanzouDirectory(fid=6073401)
 
     def change_freq(self, freq):
         self.file_pro.freq = freq
@@ -162,8 +162,8 @@ class DataFileProperty:
         return True
 
     def _load(self, start_end_fun, total=100):
-        #for i in range(total, 0, -1):
-        for i in range(1,total):
+        # for i in range(1,total):
+        for i in range(total, 0, -1):
             try:
                 self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
                 self._daily_load_and_save(self.file_pro)
