@@ -41,14 +41,14 @@ class LoadData:
     def load(self, symbol, pbr, *args, **kwargs):
         pass
 
-    def write_data(self, data_list, cache=True, base_time=0):
+    def write_data(self, data_list, cache=True):
         self.cache_data.extend(data_list)
         if cache and len(self.cache_data) < 10000:
             return
         if len(self.cache_data) == 0:
             return
         df = pd.DataFrame(self.cache_data)
-        df = df[(df['timestamp'] >= self.unix_start-base_time) & (df['timestamp'] <= self.unix_end-base_time)]
+        df = df[(df['timestamp'] >= self.unix_start) & (df['timestamp'] <= self.unix_end)]
         self._write(json.loads(df.to_json(orient='records')))
         self.cache_data.clear()
 
@@ -60,12 +60,14 @@ class LoadDataKline(LoadData):
     def __init__(self, *args, timeframe='1m', **kwargs):
         super(LoadDataKline, self).__init__(*args, **kwargs)
         self.timeframe = timeframe
-        self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
+        self.csv_file = open(self.csv_path, mode="w")
+        self.csv_writer = csv.DictWriter(self.csv_file, delimiter=",",
                                          fieldnames=["symbol", "timestamp", "open", "close", "low", "high", "vol"])
         self.csv_writer.writeheader()
 
     def _write(self, data_list):
         self.csv_writer.writerows(data_list)
+        self.csv_file .flush()
 
     def load(self, symbol, pbr, *args, **kwargs):
         unix_temp = self.unix_start
@@ -124,13 +126,13 @@ class LoadTradeKline(LoadData):
                 result = [{
                     'symbol': trade['symbol'],
                     'id': trade['id'].replace('\n', ''),
-                    'timestamp': int(trade['timestamp'])-self.unix_start,
+                    'timestamp': int(trade['timestamp']),
                     'side': trade['side'][0],
                     'price': trade['price'],
                     'amount': trade['amount'],
                 } for trade in trades]
 
-                self.write_data(result, base_time=self.unix_start)
+                self.write_data(result)
                 #time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
